@@ -22,7 +22,10 @@ from six import string_types
 # NB: We shall not be importing other parts of pyIEM here as we then get
 # circular references.
 
-SEQNUM = re.compile(r"\001?[0-9]{3}\s?")
+SEQNUM = re.compile(r"^[0-9]{3}\s?$")
+# Setup a default logging instance for this module
+LOG = logging.getLogger("pyiem")
+LOG.addHandler(logging.NullHandler())
 
 
 class CustomFormatter(logging.Formatter):
@@ -58,7 +61,7 @@ def get_test_file(name, fponly=False):
 
 
 def logger(name="pyiem", level=None):
-    """Create a standarized logger.
+    """Get pyiem's logger with a stream handler attached.
 
     Args:
       name (str): The name of the logger to get, default pyiem
@@ -70,8 +73,8 @@ def logger(name="pyiem", level=None):
     """
     ch = logging.StreamHandler()
     ch.setFormatter(CustomFormatter())
-    logging.basicConfig(handlers=[ch])
     log = logging.getLogger(name)
+    log.addHandler(ch)
     if level is None and sys.stdout.isatty():
         level = logging.DEBUG
     log.setLevel(level if level is not None else logging.INFO)
@@ -258,34 +261,25 @@ def noaaport_text(text):
     Returns:
       text that looks noaaportish
     """
-    # Convert to LFLFCR
-    text = (
-        text.replace("\003", "")
-        .replace("\001", "")
-        .replace("\n", "\r\r\n")
-        .replace("\r\r\r\r", "\r\r")
-    )
-    lines = text.split("\r\r\n")
+    # Rectify the text to remove any stray stuff
+    text = text.replace("\003", "").replace("\001", "").replace("\r", "")
+    # trim any right hand space
+    lines = [x.rstrip() for x in text.split("\n")]
     # remove any beginning empty lines
-    while lines and lines[0] == "":
-        lines.pop(0)
-    # remove any empty ending lines
-    while lines and lines[-1] == "":
-        lines.pop(-1)
+    for pos in [0, -1]:
+        while lines and lines[pos].strip() == "":
+            lines.pop(pos)
 
     # lime 0 should be start of product sequence
-    if lines[0] != "\001":
-        lines.insert(0, "\001")
+    lines.insert(0, "\001")
     # line 1 should be the LDM sequence number 4 chars
     if not SEQNUM.match(lines[1]):
         if len(lines[1]) > 5:
             lines.insert(1, "000 ")
+    else:
+        lines[1] = f"{lines[1][:3]} "
     # last line should be the control-c, by itself
-    if lines[-1] != "\003":
-        lines.append("\003")
-    # Second line should not be blank
-    if lines[1].strip() == 0:
-        lines = [lines[0]] + lines[2:]
+    lines.append("\003")
 
     return "\r\r\n".join(lines)
 
@@ -413,7 +407,7 @@ def get_autoplot_context(fdict, cfg):
 
 
 def exponential_backoff(func, *args, **kwargs):
-    """ Exponentially backoff some function until it stops erroring
+    """Exponentially backoff some function until it stops erroring
 
     Args:
       _ebfactor (int,optional): Optional scale factor, allowing for faster test
