@@ -9,7 +9,28 @@ import matplotlib.colors as mpcolors
 import numpy as np
 from pyiem import reference
 from pyiem import plot
-from pyiem.plot import MapPlot, centered_bins
+from pyiem.plot.geoplot import windrose
+from pyiem.plot import (
+    MapPlot,
+    centered_bins,
+    pretty_bins,
+    load_bounds,
+    load_pickle_pd,
+    load_pickle_geo,
+)
+
+
+def test_depreciated():
+    """Test that our windrose is depreciated."""
+    with pytest.deprecated_call():
+        windrose("")
+
+
+def test_invalid_file():
+    """Test that we don't error out on an invalid filename."""
+    assert load_bounds("this shall not work") is None
+    assert load_pickle_pd("this shall not work") is None
+    assert not load_pickle_geo("this shall not work")
 
 
 @pytest.mark.mpl_image_compare(tolerance=0.1)
@@ -60,6 +81,15 @@ def test_illinois():
     return mp.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_issue292_nws_fill_ugcs():
+    """Test that fill_ugcs works for nws sector view."""
+    mp = MapPlot(sector="nws", title="Four Counties", nocaption=True)
+    data = {"IAC001": 10, "AKC013": 20, "HIC001": 30, "PRC001": 40}
+    mp.fill_ugcs(data)
+    return mp.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=0.1)
 def test_fill_ugcs_color():
     """Provide an explicit color to fill_ugcs"""
@@ -127,10 +157,6 @@ def test_pcolormesh():
     vals = np.linspace(0, 1, lats.shape[0] * lons.shape[0]).reshape(
         [lats.shape[0], lons.shape[0]]
     )
-    # NB: mpl 3.3.0 does proper enforcement of sizing here.  We want the lons
-    # and lats to be +1 in size to the vals grid.
-    lons = np.append(lons, -80)
-    lats = np.append(lats, 50)
     lons, lats = np.meshgrid(lons, lats)
     mp.pcolormesh(lons, lats, vals, np.arange(0, 1, 0.1))
     return mp.fig
@@ -170,16 +196,28 @@ def test_conus2():
     return mp.fig
 
 
+def test_pretty_bins():
+    """Test that we get nice pretty bins!"""
+    a = pretty_bins(-1, 10)
+    assert abs(a[-1] - 10.5) < 0.01
+
+
 def test_centered_bins():
     """See that we can compute some nice centered bins"""
-    a = centered_bins(10, bins=9)
-    assert a[0] == -12
-    a = centered_bins(55, bins=9)
+    a = centered_bins(10)
+    assert a[0] == -10
+    a = centered_bins(55)
     assert a[0] == -56
-    a = centered_bins(99, bins=9)
+    a = centered_bins(99)
     assert a[0] == -100
-    a = centered_bins(0.9, bins=9)
-    assert a[0] == -0.9
+    a = centered_bins(99, bins=9)
+    assert a[0] == -99
+    a = centered_bins(100, on=100)
+    assert a[0] == 0
+    a = centered_bins(0.9)
+    assert abs(a[-1] - 1.2) < 0.001
+    a = centered_bins(1.2888)
+    assert abs(a[-1] - 1.6) < 0.001
 
 
 @pytest.mark.mpl_image_compare(tolerance=0.1)
@@ -395,6 +433,27 @@ def test_ugcs_lwx():
     return mp.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_ugcs_lwx_zones():
+    """Ensure that we can plot some zones in LWX CWA."""
+    mp = MapPlot(
+        sector="cwa",
+        cwa="LWX",
+        title="Two Maryland Counties",
+        subtitle="test_ugcs_lwx",
+        nocaption=True,
+    )
+    labels = {"MDZ001": "MDZ001", "MDZ008": "MDZ008"}
+    mp.fill_ugcs(
+        {"MDZ001": 1, "MDZ008": 40},
+        bins=list(range(0, 101, 10)),
+        labels=labels,
+        ilabel=True,
+        extend="min",
+    )
+    return mp.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=0.1)
 def test_ugcs_withcustomlabels():
     """Fill ugcs with provided labels."""
